function RotMovieFrameInit(axis1, axis2, axis3, angle1, angle2)
  % -----------------------------------------------------------------------
  % RotMovieFrameInit - Set ploting parameters, draw the coordinate axes 
  %                     and the title.
  %
  % Args: axis1 - 'x', 'y' or 'z': axis of the first rotation
  %       axis2 - 'x', 'y' or 'z': axis of the second rotation
  %       axis3 - 'x', 'y' or 'z': axis to align with
  %       angle1 - the angle of rotation about axis1
  %       angle2 - the angle of rotation about axis2
  %
  % Rtns: none
  % -----------------------------------------------------------------------

  % setup the plottng parameters for the frame
  newplot; hold on; grid on; view(135,12.5);
  set(gcf, 'Renderer', 'OpenGL');

  title(sprintf( ... % [176 ''] is the degrees symbol
    '%s%s%s: %.1f%s, %.1f%s', axis1, axis2, axis3, ...
    angle1*180/pi, [176 ''], angle2*180/pi, [176 ''] ...
  ));

  % draw the coordinate axes
  PlotFig3([0 0 0; 1  0  0]', [1 0], [.7 .3 .3]); % positive x axis
  PlotFig3([0 0 0; 0  1  0]', [1 0], [.3 .7 .3]); % positive y axis
  PlotFig3([0 0 0; 0  0  1]', [1 0], [.3 .3 .7]); % positive z axis

  axis([0 1 0 1 0 1], 'square');
end
